@@ -27,5 +27,15 @@ def api_get(table,kwargs:dict):
             else:
                 sql += f' AND {key}=${key}'
     entries = table.select_by_sql(sql,k)
-    return_entries = [entry.to_dict() for entry in entries]
+    return_entries = list()
+    for entry in entries:
+        dict_entry = entry.to_dict(related_objects=True)
+        for col_name in dict_entry:
+            if type(dict_entry[col_name]) in table._database_.entities.values():
+                if len(type(dict_entry[col_name])._pk_attrs_)>1:
+                    dict_entry[col_name] = dict_entry[col_name].to_dict()
+                else:
+                    dict_entry[col_name] = getattr(dict_entry[col_name], type(dict_entry[col_name])._pk_attrs_[0].name)
+        return_entries.append(dict_entry)
+
     return return_entries
\ No newline at end of file
